==> vue-tk-date-time-1.1.5.tgz: package/README.md <==
# vue-tk-date-time

这是一个人二开项目
UI部分借鉴了  [vue-persian-datetime-picker](https://talkhabi.github.io/vue-persian-datetime-picker) 真的做的很棒，可惜是阿拉伯的日期显示方式
### 更新日志

2019.9.26 解决选择周类型 解决选择最后一天再切换上下月出现时间不对问题

### 图例

![](https://github.com/mayufo/vue-date-time-m/blob/master/img.gif)

### 在线demo
[demo](https://mayufo.github.io/vue-date-time-m/)

### 更新

#### 1.0.27
 1. 增加了时间的间隔，详情可见demo
 2. 可以选择年月日时，而不选择分钟

### npm

```
npm install vue-tk-date-time
```

### 主要属性(说明)
```
type 时间控件类型
-- tkTime   显示 年月日时分 新增
-- week     显示 年月日 新增 返回是一个对象 beginDate endDate
-- dateTime 显示 年月日时分 默认值
-- date     显示 年月日
-- time     显示 时分
-- year     显示 年
-- month    显示 月
min  min不在可选范围
max  max不在可选范围
value 日期选中的值，默认今天
textAlign 头部文字对齐方式,可以选left\center\right
minutesInterval  分钟间隔 1\2\3\4\5\6\10\12\15\20\30\60
timeStyle 风格属性（默认为1 老风格,我自己新建了一个风格2）
cancelText 取消按钮的文本
confirmText 确认按钮的文本
```

### use
- main.js

```
import dateTime from 'vue-tk-date-time';
Vue.component('data-time', dateTime);
```

- in component
```
        <template>
          <div class="date-time-item">
            <div class="date-time-input" @click="show">{{ data }}</div>
            <d-date-time ref="dateTime"
                         type="date"
                         @confirm="select"></d-date-time>
          </div>
        </template>

        <script>
          import DateTime from 'vue-tk-date-time'
          export default {
            data(){
              return {
                data: ''
              }
            },
            components: {
              DateTime
            },
            methods: {
              //  展示日期组件
              show () {
                this.$refs.dateTime.show()
              },
              // 日期组件回调
              select (val) {
                this.data = val
              }
            }
          }
        </script>
```

==> vue-tk-date-time-1.1.6.tgz: package/README.md <==
# vue-tk-date-time

这是一个人二开项目
UI部分借鉴了  [vue-persian-datetime-picker](https://talkhabi.github.io/vue-persian-datetime-picker) 真的做的很棒，可惜是阿拉伯的日期显示方式
### 更新日志

2019.9.26 解决选择周类型 解决选择最后一天再切换上下月出现时间不对问题 必须传timeStyle =2
2019.9.26 解决选择季度类型 必须传timeStyle =2

### 图例

![](https://github.com/mayufo/vue-date-time-m/blob/master/img.gif)

### 在线demo
[demo](https://mayufo.github.io/vue-date-time-m/)

### 更新

#### 1.0.27
 1. 增加了时间的间隔，详情可见demo
 2. 可以选择年月日时，而不选择分钟

### npm

```
npm install vue-tk-date-time
```

### 主要属性(说明)
```
type 时间控件类型
-- tkTime   显示 年月日时分 新增
-- quarter  显示 年月日 季度 新增 返回是一个对象 beginDate endDate
-- week     显示 年月日 周 新增 返回是一个对象 beginDate endDate
-- dateTime 显示 年月日时分 默认值
-- date     显示 年月日
-- time     显示 时分
-- year     显示 年
-- month    显示 月
min  min不在可选范围
max  max不在可选范围
value 日期选中的值，默认今天
textAlign 头部文字对齐方式,可以选left\center\right
minutesInterval  分钟间隔 1\2\3\4\5\6\10\12\15\20\30\60
timeStyle 风格属性（默认为1 老风格,我自己新建了一个风格2）
cancelText 取消按钮的文本
confirmText 确认按钮的文本
```

### use
- main.js

```
import dateTime from 'vue-tk-date-time';
Vue.component('data-time', dateTime);
```

- in component
```
        <template>
          <div class="date-time-item">
            <div class="date-time-input" @click="show">{{ data }}</div>
            <d-date-time ref="dateTime"
                         type="date"
                         @confirm="select"></d-date-time>
          </div>
        </template>

        <script>
          import DateTime from 'vue-tk-date-time'
          export default {
            data(){
              return {
                data: ''
              }
            },
            components: {
              DateTime
            },
            methods: {
              //  展示日期组件
              show () {
                this.$refs.dateTime.show()
              },
              // 日期组件回调
              select (val) {
                this.data = val
              }
            }
          }
        </script>
```
